@@ -10,6 +10,10 @@ from dbt_airflow_factory.k8s.k8s_parameters_loader import (
 )
 from dbt_airflow_factory.operator import DbtRunOperatorBuilder
 from dbt_airflow_factory.tasks_builder.builder import DbtAirflowTasksBuilder
+from dbt_airflow_factory.tasks_builder.gateway import (
+    GatewayConfiguration,
+    TaskGraphConfiguration,
+)
 from dbt_airflow_factory.tasks_builder.parameters import TasksBuildingParameters
 
 
@@ -65,9 +69,16 @@ class DbtAirflowTasksBuilderFactory:
         dbt_params = self._create_dbt_config()
         execution_env_type = self._read_execution_env_type()
         tasks_airflow_config = self._create_tasks_airflow_config()
+
         return DbtAirflowTasksBuilder(
             tasks_airflow_config,
             self._create_operator_builder(execution_env_type, dbt_params),
+            gateway_config=TaskGraphConfiguration(
+                GatewayConfiguration(
+                    separation_schemas=self.airflow_config.get("save_points", []),
+                    gateway_task_name="gateway",
+                )
+            ),
         )
 
     def _create_tasks_airflow_config(self) -> TasksBuildingParameters:
